Module: OmnivideoAi
- Defined in:
- lib/omnivideo_ai.rb
Constant Summary collapse
- VERSION =
"0.1.0"- WEBSITE =
"https://omnivideo.video"- SUPPORT =
"support@omnivideo.video"
Class Method Summary collapse
Class Method Details
.info ⇒ Object
6 7 8 9 10 11 12 13 14 |
# File 'lib/omnivideo_ai.rb', line 6 def self.info { name: "Omni Video", title: "Omni Video AI Generator for Text and Image to Video", website: WEBSITE, support: SUPPORT, description: "Create polished AI videos from prompts, images, and references with Omni Video for ads, social posts, product demos, and launch stories." } end |